==> ecs-1.122.0-sources.jar: software/amazon/awscdk/services/ecs/BuiltInAttributes.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The built-in container instance attributes.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-08T20:44:44.441Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.BuiltInAttributes")
public class BuiltInAttributes extends software.amazon.jsii.JsiiObject {

    protected BuiltInAttributes(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BuiltInAttributes(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AMI_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "AMI_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        AVAILABILITY_ZONE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "AVAILABILITY_ZONE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        INSTANCE_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "INSTANCE_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        INSTANCE_TYPE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "INSTANCE_TYPE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        OS_TYPE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "OS_TYPE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BuiltInAttributes() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * The AMI id the instance is using.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String AMI_ID;

    /**
     * The AvailabilityZone where the instance is running in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String AVAILABILITY_ZONE;

    /**
     * The id of the instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String INSTANCE_ID;

    /**
     * The EC2 instance type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String INSTANCE_TYPE;

    /**
     * The operating system of the instance.
     * <p>
     * Either 'linux' or 'windows'.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String OS_TYPE;
}

==> ecs-1.173.0-sources.jar: software/amazon/awscdk/services/ecs/BuiltInAttributes.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The built-in container instance attributes.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ecs.*;
 * BuiltInAttributes builtInAttributes = new BuiltInAttributes();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:35.582Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.BuiltInAttributes")
public class BuiltInAttributes extends software.amazon.jsii.JsiiObject {

    protected BuiltInAttributes(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BuiltInAttributes(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AMI_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "AMI_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        AVAILABILITY_ZONE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "AVAILABILITY_ZONE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        INSTANCE_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "INSTANCE_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        INSTANCE_TYPE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "INSTANCE_TYPE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        OS_TYPE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "OS_TYPE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BuiltInAttributes() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * The AMI id the instance is using.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String AMI_ID;

    /**
     * The AvailabilityZone where the instance is running in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String AVAILABILITY_ZONE;

    /**
     * The id of the instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String INSTANCE_ID;

    /**
     * The EC2 instance type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String INSTANCE_TYPE;

    /**
     * The operating system of the instance.
     * <p>
     * Either 'linux' or 'windows'.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String OS_TYPE;
}
